summaryrefslogtreecommitdiffstats
path: root/tderesources/caldav/preferences.h
diff options
context:
space:
mode:
Diffstat (limited to 'tderesources/caldav/preferences.h')
-rw-r--r--tderesources/caldav/preferences.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tderesources/caldav/preferences.h b/tderesources/caldav/preferences.h
index 0c4532cf..d54d7d4e 100644
--- a/tderesources/caldav/preferences.h
+++ b/tderesources/caldav/preferences.h
@@ -33,7 +33,7 @@ namespace KCal {
/**
* This class provides access to ResourceCalDav preferences.
* It inherits auto-generated CalDavPrefsSkel class to add password-handling code.
* KWallet is used for storing passwords.
* It also adds code to allow multiple CalDAV resources to store settings in the same
* config file.
*/
@@ -109,7 +109,7 @@ protected:
/**
* Returns the wallet or NULL, if the wallet can't be obtained.
*/
- KWallet::Wallet* getWallet();
+ TDEWallet::Wallet* getWallet();
/**
* Tries to set a working folder for the wallet. If the wallet is not configured yet, does nothing.
@@ -150,7 +150,7 @@ private:
static const TQString WALLET_FOLDER;
static const TQString WALLET_PWD_SUFFIX;
- KWallet::Wallet* mWallet;
+ TDEWallet::Wallet* mWallet;
bool mNoWallet;
TQString mPrefix;
@@ -33,7 +33,7 @@ namespace KCal {
* This class provides access to ResourceCalDav preferences.
* It inherits auto-generated CalDavPrefsSkel class to add password-handling code.
- * KWallet is used for storing passwords.
+ * TDEWallet is used for storing passwords.
* It also adds code to allow multiple CalDAV resources to store settings in the same
* config file.